<?php

declare(strict_types = 1);

namespace Drupal\Tests\node\Functional;

use Drupal\Tests\schemadotorg\Functional\SchemaDotOrgBrowserTestBase;

/**
 * Tests Schema.org content model documentation help functionality.
 *
 * @covers schemadotorg_content_model_documentation_help()
 * @group schemadotorg
 */
class SchemaDotOrgContentModelDocumentationHelpTest extends SchemaDotOrgBrowserTestBase {

  // phpcs:disable
  /**
   * Disabled config schema checking until the schema has been fixed.
   *
   * @see https://www.drupal.org/project/epp/issues/3348759
   */
  protected $strictConfigSchema = FALSE;
  // phpcs:enable

  /**
   * Modules to enable.
   *
   * @var array
   */
  protected static $modules = [
    'block',
    'node',
    'help',
    'schemadotorg_content_model_documentation',
  ];

  /**
   * Test content model documentation help link.
   */
  public function testHelpLink(): void {
    $asset_session = $this->assertSession();

    $this->drupalLogin($this->rootUser);
    $this->drupalPlaceBlock('help_block');
    $this->createSchemaEntity('node', 'Event');

    // Check that the node add form includes a documentation link.
    $this->drupalGet('node/add/event');
    $asset_session->linkExists('Read documentation');
    $asset_session->linkByHrefExists('/admin/structure/types/manage/event/document');

    // Check that the node edit form includes a documentation link.
    $node = $this->drupalCreateNode(['type' => 'event']);
    $this->drupalGet('node/' . $node->id() . '/edit');
    $asset_session->linkExists('Read documentation');
    $asset_session->linkByHrefExists('/admin/structure/types/manage/event/document');

  }

}
