<?php

declare(strict_types = 1);

namespace Drupal\Tests\schemadotorg_content_model_documentation\Kernel;

use Drupal\Tests\schemadotorg\Kernel\SchemaDotOrgEntityKernelTestBase;

/**
 * Tests the functionality of the Schema.org content model documentation.
 *
 * @group schemadotorg
 */
class SchemaDotOrgContentModelDocumentationKernelTest extends SchemaDotOrgEntityKernelTestBase {

  // phpcs:disable
  /**
   * Disabled config schema checking until the schema has been fixed.
   *
   * @see https://www.drupal.org/project/epp/issues/3348759
   */
  protected $strictConfigSchema = FALSE;
  // phpcs:enable

  /**
   * Modules to enable.
   *
   * @var array
   */
  protected static $modules = [
    'content_model_documentation',
    'path_alias',
    'schemadotorg_content_model_documentation',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    $this->installConfig(['content_model_documentation', 'schemadotorg_content_model_documentation']);
    $this->installConfig(['content_model_documentation', 'filter']);
    $this->installEntitySchema('path_alias');
    $this->installEntitySchema('cm_document');
  }

  /**
   * Test Schema.org content model documentation.
   */
  public function testContentModelDocumentation(): void {
    /** @var \Drupal\content_model_documentation\CMDocumentStorageInterface $cm_document_storage */
    $cm_document_storage = $this->entityTypeManager->getStorage('cm_document');

    // Check node entity is NOT documentable.
    $this->assertNull($this->config('content_model_documentation.settings')->get('node'));

    \Drupal::moduleHandler()->loadInclude('schemadotorg_content_model_documentation', 'install');
    schemadotorg_content_model_documentation_install(FALSE);

    // Check node entity is NOT documentable.
    $this->assertEquals(1, $this->config('content_model_documentation.settings')->get('node'));

    // Check that Schema.org Event content model documentation is created.
    $this->createSchemaEntity('node', 'Event');
    $cm_documents = $cm_document_storage->loadByProperties(['documented_entity' => 'node.event']);
    /** @var \Drupal\content_model_documentation\Entity\CMDocument $cm_document */
    $cm_document = reset($cm_documents);
    $this->assertTrue($cm_document->isPublished());
    $this->assertEquals(0, $cm_document->getOwnerId());
    $this->assertEquals('Event', $cm_document->label());
    $this->assertEquals('node.event', $cm_document->documented_entity->value);
    $this->assertEquals('An event happening at a certain time and location, such as a concert, lecture, or festival.', $cm_document->notes->value);
    $this->assertEquals('plain_text', $cm_document->notes->format);
  }

}
