<?php

declare(strict_types = 1);

namespace Drupal\schemadotorg_paragraphs;

use Drupal\Core\Field\FieldConfigInterface;
use Drupal\schemadotorg\SchemaDotOrgMappingInterface;

/**
 * Schema.org paragraphs manager interface.
 */
interface SchemaDotOrgParagraphsManagerInterface {

  /**
   * Implements hook_ENTITY_TYPE_presave().
   *
   * @param \Drupal\schemadotorg\SchemaDotOrgMappingInterface $mapping
   *   A Schema.org mapping.
   */
  public function mappingPresave(SchemaDotOrgMappingInterface $mapping): void;

  /**
   * Alter field storage and field values before they are created.
   *
   * @param string $schema_type
   *   The Schema.org type.
   * @param string $schema_property
   *   The Schema.org property.
   * @param array $field_storage_values
   *   Field storage config values.
   * @param array $field_values
   *   Field config values.
   * @param string|null $widget_id
   *   The plugin ID of the widget.
   * @param array $widget_settings
   *   An array of widget settings.
   * @param string|null $formatter_id
   *   The plugin ID of the formatter.
   * @param array $formatter_settings
   *   An array of formatter settings.
   */
  public function propertyFieldAlter(
    string $schema_type,
    string $schema_property,
    array &$field_storage_values,
    array &$field_values,
    ?string &$widget_id,
    array &$widget_settings,
    ?string &$formatter_id,
    array &$formatter_settings
  ): void;

  /**
   * Update Schema.org paragraph field config before it is saved.
   *
   * @param \Drupal\Core\Field\FieldConfigInterface $field_config
   *   The field config.
   */
  public function fieldConfigPresave(FieldConfigInterface $field_config): void;

}
